#line 2 "BsLexerFX.c"

#line 4 "BsLexerFX.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart (FILE *input_file ,yyscan_t yyscanner );
void yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void yypop_buffer_state (yyscan_t yyscanner );

static void yyensure_buffer_stack (yyscan_t yyscanner );
static void yy_load_buffer_state (yyscan_t yyscanner );
static void yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *yyalloc (yy_size_t ,yyscan_t yyscanner );
void *yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define yywrap(yyscanner) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 228
#define YY_END_OF_BUFFER 229
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[860] =
    {   0,
        1,    1,  168,  168,  211,  211,  214,  214,    0,    0,
      224,  224,    0,    0,  176,  176,  179,  179,  183,  183,
      187,  187,  200,  200,  193,  193,  229,  227,    1,    1,
      227,  227,  227,  227,    2,    2,  139,  138,  226,  226,
      226,  226,  137,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  136,  226,  226,   93,   94,   95,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  170,  168,  168,
      170,  212,  211,  211,  210,  215,  214,  214,  213,  218,
      218,  216,  217,  224,  224,  219,  220,  221,  222,  223,
      175,  172,  174,  174,  173,  176,  177,  181,  179,  179,

      180,  185,  183,  183,  184,  189,  187,  187,  188,  202,
      200,  200,  201,  199,  193,  193,  199,    1,    0,    5,
        0,    0,    0,    0,    2,  225,    0,    2,    0,  226,
      226,  226,  226,  226,  226,  226,  145,  226,  226,  226,
      226,  226,  226,  103,  226,  226,  226,  226,  226,  226,
      226,  109,  226,  226,  226,  226,  226,  144,  143,  112,
      226,  226,  226,  226,  226,  226,  107,  226,  226,  226,
      226,  226,  226,  226,  226,  226,   83,  226,  226,  226,
      226,  142,  141,  226,  140,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,

      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  168,    0,  169,  211,
      214,  224,  173,  176,  179,  180,  183,  184,  187,  188,
      200,  201,  193,    0,    0,    0,    0,    0,    0,    0,
        0,    2,  225,    4,    3,  226,  130,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  104,  226,  226,
      226,  226,  226,  117,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  149,  111,  226,  226,  116,  120,
      226,  226,  226,  108,  226,  134,  133,  226,  226,  226,
      226,  226,  226,  110,  226,  226,  226,  121,  226,  226,

      226,  226,  226,  148,  226,  147,  146,  226,  226,  226,
      226,  226,  131,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,    8,  226,  226,
      226,  226,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    4,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,   56,  226,  126,  226,  226,  226,  226,   82,  226,
      105,  226,   71,   55,  226,  226,  206,  226,  226,  113,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,

      226,  226,  226,  226,  106,  226,  226,   53,  226,  226,
      150,  132,  226,  226,  127,  226,  226,  226,  226,  226,
      226,  226,   45,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  100,  151,  226,  114,  226,  226,   96,  226,
      226,  226,    9,   10,   11,  226,  226,  226,  226,    6,
      226,    0,    0,    0,    0,    0,    0,  191,  190,    0,
        0,    0,    0,    0,    0,    4,  226,  158,  226,   79,
      226,  226,  226,   77,   43,  226,  226,  153,   78,  226,
      226,  226,  226,  226,  128,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,   76,  226,  226,  226,  226,

      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  156,  226,  226,  226,  226,  101,  129,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,   72,   97,   16,    7,   12,
      226,  226,  226,  226,   99,  197,  196,    0,    0,    0,
        0,  192,  182,    0,    0,  178,   62,  161,  226,  226,
      226,  226,  154,   50,  226,  226,  209,  226,  226,  226,
      226,  226,  122,  226,  226,  226,  226,  226,  207,  226,
      226,  226,  226,  226,  157,  226,  152,  226,  226,  226,
      226,   91,   90,  226,  226,  226,  102,  226,  166,  159,

      226,  226,  226,  226,  226,  123,  162,  226,  226,  226,
      226,   81,  226,  226,   75,  226,  226,  226,  226,  203,
      226,   13,   14,   15,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   98,  198,  194,    0,  171,  186,    0,
      226,  226,  226,  226,  226,  226,  226,  208,  226,  119,
      124,  163,  226,  226,  226,  226,  226,  226,  226,  118,
      226,  160,  226,  226,  226,  226,  226,  226,  226,  135,
      226,  226,  226,  115,  226,  125,  226,  226,   60,  226,
       66,  226,  226,  226,  226,  226,  226,  195,  167,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,

      226,  226,  204,  205,  226,   52,  226,   88,  226,  226,
      226,  226,  155,  226,   46,   51,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,  226,  226,  226,  226,  226,  226,  226,  226,
      226,  226,   57,   59,   63,  226,  226,  226,   86,   85,
       87,  226,  226,  226,   26,   27,   28,  226,  226,   44,
      226,  226,  226,  226,   48,   31,   32,   33,  226,  226,
      226,   80,  226,  226,  226,  226,  226,   36,  226,  226,
       64,  226,  226,   89,  226,   49,  226,  226,  226,  226,
      226,  226,   54,  226,  226,  226,  226,  226,  226,   84,

      226,  226,  165,   92,  226,   65,  226,  164,  226,   61,
       30,   29,  226,  226,  226,  226,  226,  226,   35,   34,
       47,  226,  226,   41,   39,  226,  226,  226,  226,  226,
      226,  226,   37,  226,  226,   42,  226,  226,   70,  226,
      226,  226,  226,   38,  226,  226,  226,   69,  226,  226,
       40,   73,  226,   58,   67,  226,   74,   68,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    1,    1,    1,    1,    1,
        1,    1,    7,    1,    8,    9,   10,   11,   12,   13,
       14,   15,   16,   16,   16,   16,   16,    1,    1,    1,
       17,    1,    1,    1,   18,   19,   20,   21,   22,   23,
       24,   25,   26,   27,   28,   29,   30,   31,   32,   33,
       34,   35,   36,   37,   38,   39,   40,   41,   42,   43,
        1,    1,    1,    1,   27,    1,   44,   45,   46,   47,

       48,   49,   50,   51,   52,   27,   53,   54,   55,   56,
       57,   58,   59,   60,   61,   62,   63,   64,   27,   65,
       66,   27,   67,    1,   68,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[69] =
    {   0,
        1,    1,    2,    3,    1,    1,    1,    1,    1,    1,
        4,    4,    4,    4,    4,    4,    1,    4,    4,    4,
        4,    4,    4,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    4,    4,    4,    4,    4,    4,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    1,    1
    } ;

static yyconst flex_int16_t yy_base[883] =
    {   0,
        0,    0,   67,   71,   75,   78,   81,   84,   87,   92,
       95,  100,  160,  228,   97,  113,  296,  364,  432,  500,
      568,  636,  704,  772,  116,  121, 1285, 1286,  126,  129,
     1279,   87,  129, 1273,  181,  169,  229,  260,  228,  164,
     1248,  297,  170, 1218,   90,    0, 1258,  112,  161,  104,
      167,  233,  234,  290,  160,    0, 1231,  228,  130,  147,
     1221,   93, 1221, 1232, 1224, 1214, 1212, 1286,  212,  269,
     1267, 1286,  277,  316, 1286, 1286,  327,  340, 1286, 1286,
     1286, 1286, 1286, 1286,  351, 1286, 1286, 1286, 1286, 1286,
     1286, 1286, 1286, 1286,    0,    0, 1286, 1286,  356,  380,

        0, 1286,  383,  386,    0, 1286,  389,  392,    0, 1286,
      395,  398,    0, 1286,  401,  404,  151,  407, 1266, 1286,
     1222,  155,  206, 1213,  401,    0,  407,  441,    0,    0,
     1239, 1246, 1240, 1218, 1206, 1205, 1242, 1226,  218, 1200,
     1197, 1218, 1239,    0,  370, 1202, 1235, 1217, 1222,   32,
     1197,    0, 1225, 1218, 1197, 1194, 1203,    0, 1228, 1223,
     1187, 1189,  247, 1195, 1219, 1209, 1217, 1182, 1196,  188,
      152,  203, 1182, 1201,  301, 1212,    0, 1197, 1206,   97,
     1179,    0, 1212, 1196,  271, 1190, 1171, 1197, 1205, 1206,
     1204, 1167,  296, 1163,  367,  275, 1160,  405, 1175, 1160,

     1157, 1181, 1197, 1162, 1178, 1168, 1159, 1148, 1155, 1154,
     1150, 1144, 1143, 1160, 1140, 1158,  456, 1196, 1286,  459,
      462,  465,    0,    0,  469,    0,  472,    0,  475,    0,
      478,    0,  481,  432, 1151, 1150,  435, 1151,  442, 1151,
     1149,  479,    0,  507,    0, 1143,    0, 1158, 1133, 1141,
     1143, 1162, 1168, 1132, 1141, 1139, 1137,    0, 1154, 1126,
      469, 1121, 1127, 1140,  507, 1161, 1116, 1115, 1132, 1146,
     1143, 1119, 1118, 1121,    0,    0, 1115, 1115, 1128,    0,
     1119, 1133, 1143,    0, 1114,    0,    0, 1128, 1139, 1143,
     1137,  505, 1097,    0,  301, 1132, 1125,    0, 1120, 1124,

     1110, 1092, 1095,    0, 1122,    0, 1132, 1130, 1101, 1121,
      508, 1109,    0, 1087, 1090, 1082, 1098, 1079, 1080, 1083,
     1075, 1087, 1085, 1073, 1078, 1085, 1070, 1109, 1097, 1067,
     1096, 1075, 1082, 1068, 1067, 1062, 1078,  523,  526, 1061,
     1072, 1069,  492, 1071,  498, 1065, 1067, 1067, 1062, 1065,
     1065, 1057, 1062,  550, 1286, 1053, 1076, 1059, 1062, 1049,
     1067, 1081, 1055, 1048, 1052, 1080, 1065, 1037, 1039,  487,
     1032,    0, 1059,    0,  327, 1069, 1062, 1040,    0, 1038,
        0, 1052,    0,    0, 1033, 1039,    0, 1051,  494,    0,
     1067, 1021, 1051, 1030, 1025, 1028, 1027,  542, 1034, 1025,

     1047, 1046, 1045, 1038,    0, 1035, 1016,    0, 1010, 1051,
        0,    0, 1020, 1046,    0,  514, 1042, 1039, 1010, 1015,
     1001, 1001,    0, 1014, 1013, 1012, 1009, 1000,  992,  993,
     1006, 1004,    0,    0, 1003,    0,  996,  988,    0,  988,
      999,  984,    0,    0,    0,  980,  979,  978,  994,    0,
      993,  991,  991,  986,  989,  989,  979, 1286, 1286,  985,
      984,  984,  968,  981,  576,  584,  981, 1008,  966,  989,
      978,  992,  988,    0,  961,  961,  957,    0,    0,  963,
      958,  955,  961,  997,    0,  990,  994,  986,  582,  955,
      973,  961,  946,  989,  958,    0,  970,  960,  968,  948,

      949,  946,  945,  933,  941,  938,  934,  962,  964,  955,
      954,  970,  941,  936,  967,  926,    0,    0,  961,  965,
      963,  934,  934,  923,  935,  930,  925,  914,  913,  922,
      913,  914,  952,  905,  939,    0,    0,    0,    0,  533,
      590,  595,  598,  921,    0, 1286, 1286,  918,  917,  917,
      916, 1286, 1286,  914,  915, 1286,    0,    0,  900,  903,
      940,  935,    0,    0,  937,  907,    0,  907,  906,  905,
      919,  932,    0,  930,  897,  894,  899,  886,    0,  913,
      888,  883,  909,  885,  920,  889,    0,  876,  876,  874,
      873,    0,    0,  915,  889,  894,    0,  895,    0,    0,

      854,  847,  880,  790,  818,    0,    0,  776,  814,  774,
      788,    0,  778,  812,    0,  771,  781,  784,  764,    0,
      782,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0, 1286, 1286,  776, 1286, 1286,  776,
      793,  802,  758,  785,  762,  769,  794,    0,  797,    0,
        0,    0,  771,  762,  769,  760,  792,  748,  743,    0,
      761,    0,  759,  758,  748,  756,  755,  750,  746,    0,
      765,  751,  732,    0,  737,    0,  606,  748,    0,  741,
      589,  731,  730,  642,  732,  742,  729, 1286, 1286,  713,
      712,  719,  735,  712,  717,  701,  700,  701,  703,  713,

      697,  740,    0,    0,  713,    0,  696,    0,  695,  694,
      709,  694,    0,  691,    0,    0,  729,  728,  727,  709,
      688,  697,  686,  695,  682,  692,  692,  718,  717,  716,
      698,  687,  685,  680,  685,  667,  681,  698,  671,  667,
      670,  676,    0,    0,    0,  676,  703,  666,    0,    0,
        0,  641,  647,  639,    0,  669,    0,  679,  635,    0,
      327,  220,  644,  646,    0,    0,  664,    0,  674,  636,
      643,    0,  642,  641,  640,  650,  626,  650,  638,  634,
        0,  654,  619,    0,  632,    0,  643,  656,  626,  632,
      615,  627,    0,  611,  624,  635,  648,  607,  608,    0,

      607,  606,    0,    0,  625,    0,  616,    0,  644,    0,
        0,    0,  642,  614,  602,   75,  143,  189,    0,    0,
        0,  239,  240,    0,    0,  234,  262,  299,  303,  305,
      384,  399,  462,  511,  543,    0,  558,  570,    0,  553,
      555,  579,  585,    0,  579,  572,  569,    0,  578,  571,
        0,    0,  587,    0,    0,  604,    0,    0, 1286,  840,
      845,  850,  855,  860,  865,  870,  875,  880,  885,  890,
      895,  900,  902,  907,  909,  914,  916,  918,  920,  922,
      927,  654
    } ;

static yyconst flex_int16_t yy_def[883] =
    {   0,
      859,    1,  860,  860,  861,  861,  862,  862,  863,  863,
      864,  864,  865,  865,  866,  866,  867,  867,  868,  868,
      869,  869,  870,  870,  871,  871,  859,  859,  859,  859,
      872,  859,  859,  859,  859,  859,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  859,  859,  859,
      874,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  875,  876,  859,  859,  859,  859,

      877,  859,  859,  859,  878,  859,  859,  859,  879,  859,
      859,  859,  880,  859,  859,  859,  859,  859,  872,  859,
      859,  859,  859,  859,  859,  881,  859,  859,  882,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  859,  874,  859,  859,
      859,  859,  875,  876,  859,  877,  859,  878,  859,  879,
      859,  880,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  881,  859,  882,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  859,  859,  859,  859,  859,  859,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  859,  859,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,

      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  873,  873,  873,  873,    0,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859
    } ;

static yyconst flex_int16_t yy_nxt[1355] =
    {   0,
       28,   29,   30,   29,   31,   32,   28,   33,   28,   34,
       35,   36,   36,   36,   36,   36,   28,   37,   38,   39,
       40,   41,   42,   43,   44,   45,   46,   47,   48,   49,
       50,   51,   52,   46,   53,   54,   55,   56,   57,   58,
       46,   46,   59,   60,   46,   61,   46,   46,   62,   46,
       46,   63,   46,   46,   64,   46,   46,   46,   46,   46,
       65,   66,   67,   46,   46,   46,   28,   28,   69,   70,
       69,   71,   69,   70,   69,   71,   73,   74,   73,   73,
       74,   73,   77,   78,   77,   77,   78,   77,   81,  267,
       81,   75,  268,   81,   75,   81,   85,   85,   85,   97,

       97,   85,   85,   85,  831,   86,   87,   88,   89,   90,
       86,   87,   88,   89,   90,   97,   97,  115,  116,  115,
      163,  117,  115,  116,  115,  174,  117,  118,  118,  118,
      118,  118,  118,  121,  122,  175,  210,  166,  123,  125,
      125,  125,  125,  125,  125,  164,  211,   79,  167,  124,
       79,  205,  206,   82,   83,  168,  301,  302,   82,   83,
       91,   92,   93,   94,   91,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,   91,   91,  127,  169,  128,
      128,  128,  128,  128,  128,  147,  170,  158,  159,  127,
      832,  128,  128,  128,  128,  128,  128,  176,  234,  148,

      207,  289,  235,  197,  171,  149,  160,  198,  237,  208,
      238,  150,  172,  217,  217,  217,  290,  161,  287,  199,
      151,  129,  288,  173,  177,  200,   91,   91,   91,   92,
       93,   94,   91,   91,   91,   91,   91,   91,   91,   91,
       91,   91,   91,   91,   91,  129,  131,  142,  833,  132,
      178,  182,  183,  202,  239,  184,  143,  185,  291,  133,
      292,  240,  203,  792,  179,  254,  279,  144,  793,  186,
      217,  217,  217,  834,  255,  134,  180,  137,  220,  220,
      220,  187,  135,  835,  145,  280,  136,  204,  306,  307,
      146,  138,  181,  836,   91,   91,   98,   99,  100,   99,

       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,   98,   98,  139,  153,  837,  140,  220,  220,  220,
      295,  188,  320,  296,  189,  141,  190,  191,  221,  221,
      221,  154,  401,  192,  321,  193,  297,  194,  402,  315,
      155,  221,  221,  221,  485,  790,  195,  316,  156,  791,
      838,  196,  222,  222,  222,  839,  157,  225,  225,  225,
      840,  486,   98,   98,   98,   99,  100,   99,   98,   98,
       98,   98,   98,   98,   98,   98,   98,   98,   98,   98,
       98,  225,  225,  225,  227,  227,  227,  227,  227,  227,
      229,  229,  229,  229,  229,  229,  231,  231,  231,  231,

      231,  231,  233,  233,  233,  233,  233,  233,  118,  118,
      118,  242,  242,  242,  242,  242,  242,  244,  244,  244,
      244,  244,  244,  260,  261,  262,  318,  841,  842,  319,
       98,   98,  102,  103,  104,  103,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  102,  102,  102,  127,
      323,  128,  128,  128,  128,  128,  128,  217,  217,  217,
      220,  220,  220,  221,  221,  221,  222,  222,  222,  324,
      225,  225,  225,  227,  227,  227,  229,  229,  229,  231,
      231,  231,  233,  233,  233,  343,  347,  344,  350,  242,
      242,  242,  242,  242,  242,  348,  843,  351,  102,  102,

      102,  103,  104,  103,  102,  102,  102,  102,  102,  102,
      102,  102,  102,  102,  102,  102,  102,  244,  244,  244,
      244,  244,  244,  369,  374,  415,  370,  397,  354,  355,
      481,  518,  375,  416,  398,  443,  444,  445,  446,  447,
      448,  376,  417,  452,  455,  622,  623,  624,  519,  482,
      844,  495,  453,  456,  354,  355,  465,  465,  496,  399,
      466,  466,  466,  466,  466,  466,  102,  102,  106,  107,
      108,  107,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  106,  106,  504,  466,  466,  466,  466,
      466,  466,  845,  505,  466,  466,  466,  466,  466,  466,

      575,  576,  625,  626,  627,  846,  355,  628,  629,  630,
      631,  632,  633,  847,  848,  849,  577,  717,  718,  719,
      723,  578,  850,  724,  851,  720,  852,  853,  725,  854,
      855,  856,  355,  857,  106,  106,  106,  107,  108,  107,
      106,  106,  106,  106,  106,  106,  106,  106,  106,  106,
      106,  106,  106,  728,  729,  730,  858,  245,  830,  829,
      828,  731,  827,  826,  825,  824,  823,  822,  821,  820,
      819,  818,  817,  816,  815,  814,  813,  812,  811,  810,
      809,  808,  807,  806,  805,  804,  803,  802,  801,  800,
      799,  798,  797,  796,  795,  794,  789,  788,  787,  786,

      785,  784,  106,  106,  110,  111,  112,  111,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  110,
      110,  783,  782,  781,  780,  779,  778,  777,  776,  775,
      774,  773,  772,  771,  770,  769,  768,  767,  766,  765,
      764,  763,  762,  761,  760,  759,  758,  757,  756,  755,
      754,  753,  752,  751,  750,  749,  748,  747,  746,  745,
      744,  743,  742,  741,  740,  739,  738,  737,  736,  735,
      110,  110,  110,  111,  112,  111,  110,  110,  110,  110,
      110,  110,  110,  110,  110,  110,  110,  110,  110,  734,
      733,  732,  727,  726,  722,  721,  716,  715,  714,  713,

      712,  711,  710,  709,  708,  707,  706,  705,  704,  703,
      702,  701,  700,  699,  698,  697,  696,  695,  694,  693,
      692,  691,  690,  689,  688,  687,  686,  685,  684,  683,
      682,  681,  680,  679,  678,  677,  676,  675,  110,  110,
       68,   68,   68,   68,   68,   72,   72,   72,   72,   72,
       76,   76,   76,   76,   76,   80,   80,   80,   80,   80,
       84,   84,   84,   84,   84,   95,   95,   95,   95,   95,
       96,   96,   96,   96,   96,  101,  101,  101,  101,  101,
      105,  105,  105,  105,  105,  109,  109,  109,  109,  109,
      113,  113,  113,  113,  113,  114,  114,  114,  114,  114,

      119,  674,  119,  119,  119,  130,  130,  218,  673,  218,
      218,  218,  223,  223,  224,  672,  671,  224,  224,  226,
      226,  228,  228,  230,  230,  232,  232,  243,  670,  243,
      243,  243,  669,  668,  667,  666,  665,  664,  663,  662,
      661,  660,  659,  658,  657,  656,  655,  654,  653,  652,
      651,  650,  649,  648,  647,  646,  645,  644,  643,  642,
      641,  640,  639,  638,  637,  636,  635,  634,  621,  620,
      619,  618,  617,  616,  615,  614,  613,  612,  611,  610,
      609,  608,  607,  606,  605,  604,  603,  602,  601,  600,
      599,  598,  597,  596,  595,  594,  593,  592,  591,  590,

      589,  588,  587,  586,  585,  584,  583,  582,  581,  580,
      579,  574,  573,  572,  571,  570,  569,  568,  567,  566,
      565,  564,  563,  562,  561,  560,  559,  558,  557,  556,
      555,  554,  553,  552,  551,  550,  549,  548,  547,  546,
      545,  544,  543,  542,  541,  540,  539,  538,  537,  536,
      535,  534,  533,  532,  531,  530,  529,  528,  527,  526,
      525,  524,  523,  522,  521,  520,  517,  516,  515,  514,
      513,  512,  511,  510,  509,  508,  507,  506,  503,  502,
      501,  500,  499,  498,  497,  494,  493,  492,  491,  490,
      489,  488,  487,  484,  483,  480,  479,  478,  477,  476,

      475,  474,  473,  472,  471,  470,  469,  468,  467,  464,
      463,  462,  461,  460,  459,  458,  457,  454,  451,  450,
      449,  442,  441,  440,  439,  438,  437,  436,  435,  434,
      433,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      423,  422,  421,  420,  419,  418,  414,  413,  412,  411,
      410,  409,  408,  407,  406,  405,  404,  403,  400,  396,
      395,  394,  393,  392,  391,  390,  389,  388,  387,  386,
      385,  384,  383,  382,  381,  380,  379,  378,  377,  373,
      372,  371,  368,  367,  366,  365,  364,  363,  362,  361,
      360,  359,  358,  357,  356,  353,  352,  349,  346,  345,

      219,  342,  341,  340,  339,  338,  337,  336,  335,  334,
      333,  332,  331,  330,  329,  328,  327,  326,  325,  322,
      317,  314,  313,  312,  311,  310,  309,  308,  305,  304,
      303,  300,  299,  298,  294,  293,  286,  285,  284,  283,
      282,  281,  278,  277,  276,  275,  274,  273,  272,  271,
      270,  269,  266,  265,  264,  263,  259,  258,  257,  256,
      253,  252,  251,  250,  249,  248,  247,  246,  241,  236,
      120,  219,  216,  215,  214,  213,  212,  209,  201,  165,
      162,  152,  126,  120,  859,   27,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,

      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859
    } ;

static yyconst flex_int16_t yy_chk[1355] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    3,    3,
        3,    3,    4,    4,    4,    4,    5,    5,    5,    6,
        6,    6,    7,    7,    7,    8,    8,    8,    9,  150,
        9,    5,  150,   10,    6,   10,   11,   11,   11,   15,

       15,   12,   12,   12,  816,   11,   11,   11,   11,   11,
       12,   12,   12,   12,   12,   16,   16,   25,   25,   25,
       45,   25,   26,   26,   26,   50,   26,   29,   29,   29,
       30,   30,   30,   32,   32,   50,   62,   48,   32,   33,
       33,   33,   33,   33,   33,   45,   62,    7,   48,   32,
        8,   59,   59,    9,    9,   48,  180,  180,   10,   10,
       13,   13,   13,   13,   13,   13,   13,   13,   13,   13,
       13,   13,   13,   13,   13,   13,   13,   36,   49,   36,
       36,   36,   36,   36,   36,   40,   49,   43,   43,   35,
      817,   35,   35,   35,   35,   35,   35,   51,  117,   40,

       60,  171,  117,   55,   49,   40,   43,   55,  122,   60,
      122,   40,   49,   69,   69,   69,  171,   43,  170,   55,
       40,   35,  170,   49,   51,   55,   13,   13,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   35,   37,   39,  818,   37,
       52,   53,   53,   58,  123,   53,   39,   53,  172,   37,
      172,  123,   58,  762,   52,  139,  163,   39,  762,   53,
       70,   70,   70,  822,  139,   37,   52,   38,   73,   73,
       73,   53,   37,  823,   39,  163,   37,   58,  185,  185,
       39,   38,   52,  826,   14,   14,   17,   17,   17,   17,

       17,   17,   17,   17,   17,   17,   17,   17,   17,   17,
       17,   17,   17,   38,   42,  827,   38,   74,   74,   74,
      175,   54,  196,  175,   54,   38,   54,   54,   77,   77,
       77,   42,  295,   54,  196,   54,  175,   54,  295,  193,
       42,   78,   78,   78,  375,  761,   54,  193,   42,  761,
      828,   54,   85,   85,   85,  829,   42,   99,   99,   99,
      830,  375,   17,   17,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,  100,  100,  100,  103,  103,  103,  104,  104,  104,
      107,  107,  107,  108,  108,  108,  111,  111,  111,  112,

      112,  112,  115,  115,  115,  116,  116,  116,  118,  118,
      118,  125,  125,  125,  125,  125,  125,  127,  127,  127,
      127,  127,  127,  145,  145,  145,  195,  831,  832,  195,
       18,   18,   19,   19,   19,   19,   19,   19,   19,   19,
       19,   19,   19,   19,   19,   19,   19,   19,   19,  128,
      198,  128,  128,  128,  128,  128,  128,  217,  217,  217,
      220,  220,  220,  221,  221,  221,  222,  222,  222,  198,
      225,  225,  225,  227,  227,  227,  229,  229,  229,  231,
      231,  231,  233,  233,  233,  234,  237,  234,  239,  242,
      242,  242,  242,  242,  242,  237,  833,  239,   19,   19,

       20,   20,   20,   20,   20,   20,   20,   20,   20,   20,
       20,   20,   20,   20,   20,   20,   20,  244,  244,  244,
      244,  244,  244,  261,  265,  311,  261,  292,  244,  244,
      370,  416,  265,  311,  292,  338,  338,  338,  339,  339,
      339,  265,  311,  343,  345,  540,  540,  540,  416,  370,
      834,  389,  343,  345,  244,  244,  354,  354,  389,  292,
      354,  354,  354,  354,  354,  354,   20,   20,   21,   21,
       21,   21,   21,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   21,   21,   21,  398,  465,  465,  465,  465,
      465,  465,  835,  398,  466,  466,  466,  466,  466,  466,

      489,  489,  541,  541,  541,  837,  466,  542,  542,  542,
      543,  543,  543,  838,  840,  841,  489,  677,  677,  677,
      681,  489,  842,  681,  843,  677,  845,  846,  681,  847,
      849,  850,  466,  853,   21,   21,   22,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   22,   22,   22,   22,
       22,   22,   22,  684,  684,  684,  856,  882,  815,  814,
      813,  684,  809,  807,  805,  802,  801,  799,  798,  797,
      796,  795,  794,  792,  791,  790,  789,  788,  787,  785,
      783,  782,  780,  779,  778,  777,  776,  775,  774,  773,
      771,  770,  769,  767,  764,  763,  759,  758,  756,  754,

      753,  752,   22,   22,   23,   23,   23,   23,   23,   23,
       23,   23,   23,   23,   23,   23,   23,   23,   23,   23,
       23,  748,  747,  746,  742,  741,  740,  739,  738,  737,
      736,  735,  734,  733,  732,  731,  730,  729,  728,  727,
      726,  725,  724,  723,  722,  721,  720,  719,  718,  717,
      714,  712,  711,  710,  709,  707,  705,  702,  701,  700,
      699,  698,  697,  696,  695,  694,  693,  692,  691,  690,
       23,   23,   24,   24,   24,   24,   24,   24,   24,   24,
       24,   24,   24,   24,   24,   24,   24,   24,   24,  687,
      686,  685,  683,  682,  680,  678,  675,  673,  672,  671,

      669,  668,  667,  666,  665,  664,  663,  661,  659,  658,
      657,  656,  655,  654,  653,  649,  647,  646,  645,  644,
      643,  642,  641,  640,  637,  621,  619,  618,  617,  616,
      614,  613,  611,  610,  609,  608,  605,  604,   24,   24,
      860,  860,  860,  860,  860,  861,  861,  861,  861,  861,
      862,  862,  862,  862,  862,  863,  863,  863,  863,  863,
      864,  864,  864,  864,  864,  865,  865,  865,  865,  865,
      866,  866,  866,  866,  866,  867,  867,  867,  867,  867,
      868,  868,  868,  868,  868,  869,  869,  869,  869,  869,
      870,  870,  870,  870,  870,  871,  871,  871,  871,  871,

      872,  603,  872,  872,  872,  873,  873,  874,  602,  874,
      874,  874,  875,  875,  876,  601,  598,  876,  876,  877,
      877,  878,  878,  879,  879,  880,  880,  881,  596,  881,
      881,  881,  595,  594,  591,  590,  589,  588,  586,  585,
      584,  583,  582,  581,  580,  578,  577,  576,  575,  574,
      572,  571,  570,  569,  568,  566,  565,  562,  561,  560,
      559,  555,  554,  551,  550,  549,  548,  544,  535,  534,
      533,  532,  531,  530,  529,  528,  527,  526,  525,  524,
      523,  522,  521,  520,  519,  516,  515,  514,  513,  512,
      511,  510,  509,  508,  507,  506,  505,  504,  503,  502,

      501,  500,  499,  498,  497,  495,  494,  493,  492,  491,
      490,  488,  487,  486,  484,  483,  482,  481,  480,  477,
      476,  475,  473,  472,  471,  470,  469,  468,  467,  464,
      463,  462,  461,  460,  457,  456,  455,  454,  453,  452,
      451,  449,  448,  447,  446,  442,  441,  440,  438,  437,
      435,  432,  431,  430,  429,  428,  427,  426,  425,  424,
      422,  421,  420,  419,  418,  417,  414,  413,  410,  409,
      407,  406,  404,  403,  402,  401,  400,  399,  397,  396,
      395,  394,  393,  392,  391,  388,  386,  385,  382,  380,
      378,  377,  376,  373,  371,  369,  368,  367,  366,  365,

      364,  363,  362,  361,  360,  359,  358,  357,  356,  353,
      352,  351,  350,  349,  348,  347,  346,  344,  342,  341,
      340,  337,  336,  335,  334,  333,  332,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  321,  320,  319,
      318,  317,  316,  315,  314,  312,  310,  309,  308,  307,
      305,  303,  302,  301,  300,  299,  297,  296,  293,  291,
      290,  289,  288,  285,  283,  282,  281,  279,  278,  277,
      274,  273,  272,  271,  270,  269,  268,  267,  266,  264,
      263,  262,  260,  259,  257,  256,  255,  254,  253,  252,
      251,  250,  249,  248,  246,  241,  240,  238,  236,  235,

      218,  216,  215,  214,  213,  212,  211,  210,  209,  208,
      207,  206,  205,  204,  203,  202,  201,  200,  199,  197,
      194,  192,  191,  190,  189,  188,  187,  186,  184,  183,
      181,  179,  178,  176,  174,  173,  169,  168,  167,  166,
      165,  164,  162,  161,  160,  159,  157,  156,  155,  154,
      153,  151,  149,  148,  147,  146,  143,  142,  141,  140,
      138,  137,  136,  135,  134,  133,  132,  131,  124,  121,
      119,   71,   67,   66,   65,   64,   63,   61,   57,   47,
       44,   41,   34,   31,   27,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,

      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  859,  859,  859,  859,
      859,  859,  859,  859
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[229] =
    {   0,
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 
    0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 
    1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0, 
    0, 0, 0, 0, 1, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
#line 2 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
#include "BsParserFX.h"

#define YY_USER_ACTION yylloc->first_column = yycolumn + 1; yylloc->first_line = yylineno + 1; yycolumn += (int)yyleng; yylloc->filename = getCurrentFilename(yyextra);
#define YY_USER_INIT yylineno = 0; yycolumn = 0;
#define YY_NO_UNISTD_H 1
/* Start conditions */












#line 1068 "BsLexerFX.c"

#define INITIAL 0
#define INCLUDE 1
#define CODEBLOCK_HEADER 2
#define CODEBLOCK_EQUALS 3
#define CODEBLOCK 4
#define CODEBLOCK_END 5
#define DEFINE_COND 6
#define DEFINE_COND_EXPR 7
#define UNDEF_COND 8
#define CONDITIONAL_IF 9
#define CONDITIONAL_IFN 10
#define CONDITIONAL_ELIF 11
#define CONDITIONAL_IGNORE 12

/*windows compatibility case*/
#include <io.h>
#define isatty _isatty
#define fileno _fileno
    
#define YY_EXTRA_TYPE struct tagParseState *

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy (yyscan_t yyscanner );

int yyget_debug (yyscan_t yyscanner );

void yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra (yyscan_t yyscanner );

void yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *yyget_in (yyscan_t yyscanner );

void yyset_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *yyget_out (yyscan_t yyscanner );

void yyset_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t yyget_leng (yyscan_t yyscanner );

char *yyget_text (yyscan_t yyscanner );

int yyget_lineno (yyscan_t yyscanner );

void yyset_lineno (int line_number ,yyscan_t yyscanner );

int yyget_column  (yyscan_t yyscanner );

void yyset_column (int column_no ,yyscan_t yyscanner );

YYSTYPE * yyget_lval (yyscan_t yyscanner );

void yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *yyget_lloc (yyscan_t yyscanner );
    
        void yyset_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap (yyscan_t yyscanner );
#else
extern int yywrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

#line 38 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"


#line 1323 "BsLexerFX.c"

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		yy_load_buffer_state(yyscanner );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 860 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 859 );
		yy_cp = yyg->yy_last_accepting_cpos;
		yy_current_state = yyg->yy_last_accepting_state;

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 40 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 41 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = atoi(yytext); return TOKEN_INTEGER; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 42 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = (int)strtol(yytext, 0, 0); return TOKEN_INTEGER; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 43 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->floatValue = (float)atof(yytext); return TOKEN_FLOAT; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 44 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->strValue = mmalloc_strdup(yyextra->memContext, yytext); return TOKEN_STRING; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 45 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 1; return TOKEN_BOOLEAN; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 46 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0; return TOKEN_BOOLEAN; }
	YY_BREAK
/* Value types */
case 8:
YY_RULE_SETUP
#line 50 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Int; return TOKEN_INTTYPE; } 
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 51 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Int2; return TOKEN_INT2TYPE; } 
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 52 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Int3; return TOKEN_INT3TYPE; } 
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 53 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Int4; return TOKEN_INT4TYPE; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 55 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Float; return TOKEN_FLOATTYPE; } 
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 56 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Float2; return TOKEN_FLOAT2TYPE; } 
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 57 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Float3; return TOKEN_FLOAT3TYPE; } 
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 58 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Float4; return TOKEN_FLOAT4TYPE; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 59 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Color; return TOKEN_COLORTYPE; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 61 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat2x2; return TOKEN_MAT2x2TYPE; } 
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 62 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat2x3; return TOKEN_MAT2x3TYPE; } 
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 63 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat2x4; return TOKEN_MAT2x4TYPE; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 65 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat3x2; return TOKEN_MAT3x2TYPE; } 
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 66 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat3x3; return TOKEN_MAT3x3TYPE; } 
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 67 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat3x4; return TOKEN_MAT3x4TYPE; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 69 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat4x2; return TOKEN_MAT4x2TYPE; } 
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 70 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat4x3; return TOKEN_MAT4x3TYPE; } 
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 71 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Mat4x4; return TOKEN_MAT4x4TYPE; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 73 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Sampler1D; return TOKEN_SAMPLER1D; } 
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 74 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Sampler2D; return TOKEN_SAMPLER2D; } 
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 75 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Sampler3D; return TOKEN_SAMPLER3D; } 
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 76 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_SamplerCUBE; return TOKEN_SAMPLERCUBE; } 
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 77 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Sampler2DMS; return TOKEN_SAMPLER2DMS; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 79 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Texture1D; return TOKEN_TEXTURE1D; } 
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 80 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Texture2D; return TOKEN_TEXTURE2D; } 
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 81 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Texture3D; return TOKEN_TEXTURE3D; } 
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 82 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_TextureCUBE; return TOKEN_TEXTURECUBE; } 
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 83 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_Texture2DMS; return TOKEN_TEXTURE2DMS; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 85 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_ByteBuffer; return TOKEN_BYTEBUFFER; } 
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 86 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_StructBuffer; return TOKEN_STRUCTBUFFER; } 
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 88 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_TypedBufferRW; return TOKEN_RWTYPEDBUFFER; } 
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 89 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_ByteBufferRW; return TOKEN_RWBYTEBUFFER; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 90 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_StructBufferRW; return TOKEN_RWSTRUCTBUFFER; } 
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 91 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_AppendBuffer; return TOKEN_RWAPPENDBUFFER; } 
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 92 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = PT_ConsumeBuffer; return TOKEN_RWCONSUMEBUFFER; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 94 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_PARAMSBLOCK; }
	YY_BREAK
/* Shader keywords */
case 44:
YY_RULE_SETUP
#line 97 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SEPARABLE; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 98 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SORT; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 99 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_PRIORITY; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 100 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_TRANSPARENT; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 101 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_TECHNIQUE; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 102 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_PARAMETERS; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 103 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_BLOCKS; }
	YY_BREAK
/* Technique keywords */
case 51:
YY_RULE_SETUP
#line 106 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_RENDERER; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 107 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_LANGUAGE; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 108 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_PASS; }
	YY_BREAK
/* Pass keywords */
case 54:
YY_RULE_SETUP
#line 111 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCILREF; }
	YY_BREAK
/* Rasterizer state keywords */
case 55:
YY_RULE_SETUP
#line 114 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_FILLMODE; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 115 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_CULLMODE; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 116 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_DEPTHBIAS; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 117 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SDEPTHBIAS; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 118 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_DEPTHCLIP; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 119 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SCISSOR; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 120 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MULTISAMPLE; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 121 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_AALINE; }
	YY_BREAK
/* Depth-stencil state keywords */
case 63:
YY_RULE_SETUP
#line 124 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_DEPTHREAD; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 125 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_DEPTHWRITE; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 126 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_COMPAREFUNC; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 127 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCIL; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 128 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCILREADMASK; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 129 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCILWRITEMASK; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 130 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCILOPFRONT; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 131 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_STENCILOPBACK; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 132 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_FAIL; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 133 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_ZFAIL; }
	YY_BREAK
/* Blend state keywords */
case 73:
YY_RULE_SETUP
#line 136 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_ALPHATOCOVERAGE; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 137 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_INDEPENDANTBLEND; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 138 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_TARGET; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 139 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_INDEX; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 140 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_BLEND; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 141 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_COLOR; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 142 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_ALPHA; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 143 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_WRITEMASK; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 144 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SOURCE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 145 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_DEST; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 146 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_OP; }
	YY_BREAK
/* Sampler state keywords */
case 84:
YY_RULE_SETUP
#line 149 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_ADDRMODE; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 150 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MINFILTER; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 151 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MAGFILTER; }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 152 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MIPFILTER; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 153 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MAXANISO; }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 154 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MIPBIAS; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 155 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MIPMIN; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 156 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_MIPMAX; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 157 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_BORDERCOLOR; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 158 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_U; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 159 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_V; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 160 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_W; }
	YY_BREAK
/* Qualifiers */
case 96:
YY_RULE_SETUP
#line 163 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_AUTO; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 164 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_ALIAS; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 165 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_SHARED; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 166 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return TOKEN_USAGE; }
	YY_BREAK
/* State values */
case 100:
YY_RULE_SETUP
#line 169 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FMV_Wire; return TOKEN_FILLMODEVALUE; }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 170 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FMV_Solid; return TOKEN_FILLMODEVALUE; }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 172 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CMV_None; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 173 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CMV_CW; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 174 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CMV_CCW; return TOKEN_CULLMODEVALUE; }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 176 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_Fail; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 177 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_Pass; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 178 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_LT; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 179 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_LTE; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 180 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_EQ; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 181 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_NEQ; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 182 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_GTE; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 183 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = CFV_GT; return TOKEN_COMPFUNCVALUE; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 185 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Keep; return TOKEN_OPVALUE; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 186 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Zero; return TOKEN_OPVALUE; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 187 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Replace; return TOKEN_OPVALUE; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 188 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Incr; return TOKEN_OPVALUE; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 189 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Decr; return TOKEN_OPVALUE; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 190 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_IncrWrap; return TOKEN_OPVALUE; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 191 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_DecrWrap; return TOKEN_OPVALUE; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 192 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_Invert; return TOKEN_OPVALUE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 193 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_One; return TOKEN_OPVALUE; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 194 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_DestColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 195 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_SrcColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 196 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_InvDestColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 197 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_InvSrcColor; return TOKEN_OPVALUE; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 198 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_DestAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 199 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_SrcAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 200 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_InvDestAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 201 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = OV_InvSrcAlpha; return TOKEN_OPVALUE; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 203 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BOV_Add; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 204 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BOV_Subtract; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 205 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BOV_RevSubtract; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 206 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BOV_Min; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 207 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BOV_Max; return TOKEN_BLENDOPVALUE; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 209 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x0; return TOKEN_COLORMASK; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 210 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x1; return TOKEN_COLORMASK; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 211 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x2; return TOKEN_COLORMASK; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 212 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x4; return TOKEN_COLORMASK; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 213 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x8; return TOKEN_COLORMASK; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 214 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x3; return TOKEN_COLORMASK; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 215 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x5; return TOKEN_COLORMASK; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 216 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x9; return TOKEN_COLORMASK; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 217 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x6; return TOKEN_COLORMASK; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 218 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xA; return TOKEN_COLORMASK; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 219 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xC; return TOKEN_COLORMASK; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 220 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0x7; return TOKEN_COLORMASK; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 221 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xB; return TOKEN_COLORMASK; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 222 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xD; return TOKEN_COLORMASK; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 223 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xE; return TOKEN_COLORMASK; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 224 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = 0xF; return TOKEN_COLORMASK; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 226 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = AMV_Wrap; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 227 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = AMV_Mirror; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 228 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = AMV_Clamp; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 229 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = AMV_Border; return TOKEN_ADDRMODEVALUE; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 231 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_None; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 232 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_Point; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 233 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_Linear; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 234 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_Anisotropic; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 235 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_PointCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 236 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_LinearCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 237 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = FV_AnisotropicCmp; return TOKEN_FILTERVALUE; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 239 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BUV_Static; return TOKEN_BUFFERUSAGE; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 240 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = BUV_Dynamic; return TOKEN_BUFFERUSAGE; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 242 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = QST_FrontToBack; return TOKEN_QUEUETYPE; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 243 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = QST_BackToFront; return TOKEN_QUEUETYPE; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 244 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = QST_None; return TOKEN_QUEUETYPE; }
	YY_BREAK
/* Preprocessor */
case 167:
YY_RULE_SETUP
#line 247 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(INCLUDE); }
	YY_BREAK
case 168:
/* rule 168 can match eol */
YY_RULE_SETUP
#line 249 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 250 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{
	int size = 0;
	char* includeBuffer = includePush(yyextra, yytext, yylineno, yycolumn, &size);
	if(!includeBuffer)
		yyterminate();

	YY_BUFFER_STATE currentBuffer = YY_CURRENT_BUFFER;
	YY_BUFFER_STATE newBuffer = yy_scan_buffer(includeBuffer,size,yyscanner);

	yy_switch_to_buffer(currentBuffer,yyscanner);
	yypush_buffer_state(newBuffer,yyscanner);

	yylineno = 0; 
	yycolumn = 0;

	BEGIN(INITIAL);
	}
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 267 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(INCLUDE):
case YY_STATE_EOF(CODEBLOCK_HEADER):
case YY_STATE_EOF(CODEBLOCK_EQUALS):
case YY_STATE_EOF(CODEBLOCK):
case YY_STATE_EOF(CODEBLOCK_END):
case YY_STATE_EOF(DEFINE_COND):
case YY_STATE_EOF(DEFINE_COND_EXPR):
case YY_STATE_EOF(UNDEF_COND):
case YY_STATE_EOF(CONDITIONAL_IF):
case YY_STATE_EOF(CONDITIONAL_IFN):
case YY_STATE_EOF(CONDITIONAL_ELIF):
case YY_STATE_EOF(CONDITIONAL_IGNORE):
#line 269 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{
	if(!yyextra->includeStack)
		yyterminate();

	yypop_buffer_state(yyscanner);
	includePop(yyextra);
}
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 277 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(DEFINE_COND); }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 278 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 279 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ addDefine(yyextra, yytext); BEGIN(DEFINE_COND_EXPR); }
	YY_BREAK
case 174:
/* rule 174 can match eol */
YY_RULE_SETUP
#line 280 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 281 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 283 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ addDefineExpr(yyextra, yytext); BEGIN(INITIAL); }
	YY_BREAK
case 177:
/* rule 177 can match eol */
YY_RULE_SETUP
#line 284 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 286 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(UNDEF_COND); }
	YY_BREAK
case 179:
/* rule 179 can match eol */
YY_RULE_SETUP
#line 287 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 180:
YY_RULE_SETUP
#line 288 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ removeDefine(yyextra, yytext); BEGIN(INITIAL); }
	YY_BREAK
case 181:
YY_RULE_SETUP
#line 289 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 182:
YY_RULE_SETUP
#line 291 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CONDITIONAL_IF); }
	YY_BREAK
case 183:
/* rule 183 can match eol */
YY_RULE_SETUP
#line 292 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 184:
YY_RULE_SETUP
#line 293 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	int isEnabled = pushConditional(yyextra, hasDefine(yyextra, yytext));
	if(!isEnabled)
		BEGIN(CONDITIONAL_IGNORE);
	else
		BEGIN(INITIAL);
}
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 300 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 302 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CONDITIONAL_IFN); }
	YY_BREAK
case 187:
/* rule 187 can match eol */
YY_RULE_SETUP
#line 303 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 188:
YY_RULE_SETUP
#line 304 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	int isEnabled = pushConditional(yyextra, !hasDefine(yyextra, yytext));
	if(!isEnabled)
		BEGIN(CONDITIONAL_IGNORE);
	else
		BEGIN(INITIAL);
}
	YY_BREAK
case 189:
YY_RULE_SETUP
#line 311 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 190:
YY_RULE_SETUP
#line 313 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CONDITIONAL_IGNORE); }
	YY_BREAK
case 191:
YY_RULE_SETUP
#line 314 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CONDITIONAL_IGNORE); }
	YY_BREAK
case 192:
YY_RULE_SETUP
#line 316 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ popConditional(yyextra); }
	YY_BREAK
case 193:
/* rule 193 can match eol */
YY_RULE_SETUP
#line 318 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip */ }
	YY_BREAK
case 194:
YY_RULE_SETUP
#line 319 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ pushConditional(yyextra, 0); }
	YY_BREAK
case 195:
YY_RULE_SETUP
#line 320 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ pushConditional(yyextra, 0); }
	YY_BREAK
case 196:
YY_RULE_SETUP
#line 321 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	if(switchConditional(yyextra))
		BEGIN(INITIAL);
}
	YY_BREAK
case 197:
YY_RULE_SETUP
#line 325 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CONDITIONAL_ELIF); }
	YY_BREAK
case 198:
YY_RULE_SETUP
#line 326 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	if(popConditional(yyextra))
		BEGIN(INITIAL);
}
	YY_BREAK
case 199:
YY_RULE_SETUP
#line 330 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip */ }
	YY_BREAK
case 200:
/* rule 200 can match eol */
YY_RULE_SETUP
#line 332 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 201:
YY_RULE_SETUP
#line 333 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	int isEnabled = setConditional(yyextra, hasDefine(yyextra, yytext));
	if(!isEnabled)
		BEGIN(CONDITIONAL_IGNORE);
	else
		BEGIN(INITIAL);
}
	YY_BREAK
case 202:
YY_RULE_SETUP
#line 340 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
/* Code blocks */
case 203:
YY_RULE_SETUP
#line 343 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_VERTEX; }
	YY_BREAK
case 204:
YY_RULE_SETUP
#line 344 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_FRAGMENT; }
	YY_BREAK
case 205:
YY_RULE_SETUP
#line 345 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_GEOMETRY; }
	YY_BREAK
case 206:
YY_RULE_SETUP
#line 346 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_HULL; }
	YY_BREAK
case 207:
YY_RULE_SETUP
#line 347 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_DOMAIN; }
	YY_BREAK
case 208:
YY_RULE_SETUP
#line 348 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_COMPUTE; }
	YY_BREAK
case 209:
YY_RULE_SETUP
#line 349 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_HEADER); return TOKEN_COMMON; }
	YY_BREAK
/* Track when the code block begins, insert all code block characters into our own buffer, record a sequential index */
/* of all code blocks in the text, and track bracket open/closed state so we know when we're done with the code block. */
/* And finally output a sequential code block index to the parser (it shouldn't be aware of anything else in the block). */
case 210:
YY_RULE_SETUP
#line 354 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK_EQUALS); return yytext[0]; }
	YY_BREAK
case 211:
/* rule 211 can match eol */
YY_RULE_SETUP
#line 355 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 212:
YY_RULE_SETUP
#line 356 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 213:
YY_RULE_SETUP
#line 358 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(CODEBLOCK); beginCodeBlock(yyextra); yyextra->numOpenBrackets = 1; return yytext[0]; }
	YY_BREAK
case 214:
/* rule 214 can match eol */
YY_RULE_SETUP
#line 359 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Skip blank */ }
	YY_BREAK
case 215:
YY_RULE_SETUP
#line 360 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 216:
YY_RULE_SETUP
#line 362 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yyextra->numOpenBrackets++; appendCodeBlock(yyextra, yytext, 1); }
	YY_BREAK
case 217:
YY_RULE_SETUP
#line 363 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ 
	yyextra->numOpenBrackets--; 

	if(yyextra->numOpenBrackets == 0)
	{
		BEGIN(CODEBLOCK_END);
		unput('0');
	}
	else
		appendCodeBlock(yyextra, yytext, 1);
}
	YY_BREAK
case 218:
/* rule 218 can match eol */
YY_RULE_SETUP
#line 374 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ appendCodeBlock(yyextra, yytext, 1); }
	YY_BREAK
/* Logic for manually inserting "Index = codeBlockIndex;". We insert arbitrary numbers which allows us to sequentially */
/* output all the tokens we need. We use only single-character values so we don't override anything in the text buffer */
/* (since the starting value was also a single character "{"). */
case 219:
YY_RULE_SETUP
#line 379 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ unput('1'); return TOKEN_INDEX; }
	YY_BREAK
case 220:
YY_RULE_SETUP
#line 380 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ unput('2'); return '='; }
	YY_BREAK
case 221:
YY_RULE_SETUP
#line 381 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->intValue = getCodeBlockIndex(yyextra); unput('3'); return TOKEN_INTEGER; }
	YY_BREAK
case 222:
YY_RULE_SETUP
#line 382 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ unput('4'); return ';'; }
	YY_BREAK
case 223:
YY_RULE_SETUP
#line 383 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ BEGIN(INITIAL); return '}'; }
	YY_BREAK
case 224:
/* rule 224 can match eol */
YY_RULE_SETUP
#line 384 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ /* Never reached */ }
	YY_BREAK
/* Catch all rules */
case 225:
YY_RULE_SETUP
#line 387 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ }
	YY_BREAK
case 226:
YY_RULE_SETUP
#line 388 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ yylval->strValue = mmalloc_strdup(yyextra->memContext, yytext); return TOKEN_IDENTIFIER; }
	YY_BREAK
case 227:
YY_RULE_SETUP
#line 389 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
{ return yytext[0]; }
	YY_BREAK
case 228:
YY_RULE_SETUP
#line 391 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 2662 "BsLexerFX.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_last_accepting_cpos;
				yy_current_state = yyg->yy_last_accepting_state;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 860 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 860 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 859);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree((void *) b->yy_ch_buf ,yyscanner );

	yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void yyset_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */

int yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 390 "..\\..\\Source\\BansheeSL\\BsLexerFX.l"


